==> jc-1.4.0.tar.gz: scm/scmClassCP.h <==
// class scm.scmClassCP

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class e634fffa307df857 scm_scmClassCP

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmClassCP_H_
#define _JC_scm_scmClassCP_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmClassCP$sub_refs	_jc_scm_scmClassCP$sub_refs;
typedef struct _jc_scm_scmClassCP$sub_nonrefs	_jc_scm_scmClassCP$sub_nonrefs;
typedef struct _jc_scm_scmClassCP$refs	_jc_scm_scmClassCP$refs;
typedef struct _jc_scm_scmClassCP$nonrefs	_jc_scm_scmClassCP$nonrefs;
typedef struct _jc_scm_scmClassCP$object	_jc_scm_scmClassCP$object;

typedef const struct _jc_scm_scmClassCP$vmethods	_jc_scm_scmClassCP$vmethods;
typedef const struct _jc_scm_scmClassCP$vtable	_jc_scm_scmClassCP$vtable;
typedef const struct _jc_scm_scmClassCP$vtype	_jc_scm_scmClassCP$vtype;

// Constructors
extern void _jc_scm_scmClassCP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmClassCP$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmClassCP$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmClassCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmClassCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmClassCP$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmClassCP$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmClassCP$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmClassCP$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmClassCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmClassCP$object *);
};

// Vtable
struct _jc_scm_scmClassCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmClassCP$vmethods	scm_scmClassCP;
};

// Vtype
struct _jc_scm_scmClassCP$vtype {
	_jc_type			type;
	_jc_scm_scmClassCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmClassCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmClassCP$refs {
    _jc_scm_scmClassCP$sub_refs	scm_scmClassCP;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmClassCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmClassCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmClassCP$sub_nonrefs	scm_scmClassCP;
};

// Object instance structure
struct _jc_scm_scmClassCP$object {
	_jc_scm_scmClassCP$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmClassCP$vtype	*vtype;
	_jc_scm_scmClassCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmClassCP$vtype _jc_scm_scmClassCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmClassCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmClassCP$class_object;

#endif	/* _JC_scm_scmClassCP_H_ */

==> jc-1.4.6.tar.gz: scm/scmClassCP.h <==
// class scm.scmClassCP

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class e634fffa307df857 scm_scmClassCP

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmClassCP_H_
#define _JC_scm_scmClassCP_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmClassCP$sub_refs	_jc_scm_scmClassCP$sub_refs;
typedef struct _jc_scm_scmClassCP$sub_nonrefs	_jc_scm_scmClassCP$sub_nonrefs;
typedef struct _jc_scm_scmClassCP$refs	_jc_scm_scmClassCP$refs;
typedef struct _jc_scm_scmClassCP$nonrefs	_jc_scm_scmClassCP$nonrefs;
typedef struct _jc_scm_scmClassCP$object	_jc_scm_scmClassCP$object;

typedef const struct _jc_scm_scmClassCP$vmethods	_jc_scm_scmClassCP$vmethods;
typedef const struct _jc_scm_scmClassCP$vtable	_jc_scm_scmClassCP$vtable;
typedef const struct _jc_scm_scmClassCP$vtype	_jc_scm_scmClassCP$vtype;

// Constructors
extern void _jc_scm_scmClassCP$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmClassCP$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmClassCP$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmClassCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmClassCP$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmClassCP$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmClassCP$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmClassCP$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmClassCP$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmClassCP$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmClassCP$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmClassCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmClassCP$vmethods	scm_scmClassCP;
};

// Vtype
struct _jc_scm_scmClassCP$vtype {
	_jc_type			type;
	_jc_scm_scmClassCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmClassCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmClassCP$refs {
    _jc_scm_scmClassCP$sub_refs	scm_scmClassCP;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmClassCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmClassCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmClassCP$sub_nonrefs	scm_scmClassCP;
};

// Object instance structure
struct _jc_scm_scmClassCP$object {
	_jc_scm_scmClassCP$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmClassCP$vtype	*vtype;
	_jc_scm_scmClassCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmClassCP$vtype _jc_scm_scmClassCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmClassCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmClassCP$class_object;

#endif	/* _JC_scm_scmClassCP_H_ */
